<?php
################################################################################################
# Russian Language Installer
# Description
# Copyright (c) 2014 Sergey Ogarkov <sogarkov@gmail.com>
# GNU GPL v.3
################################################################################################
class ControllerModuleRboseRussianLanguage extends Controller {

    private $error = array();

    public function index() {
        //Load the language file for this module
        $this->load->language('module/rbose_russian_language');

        //Set the title from the language file $_['heading_title'] string
        $this->document->setTitle($this->language->get('heading_title'));

        //This is how the language gets pulled through from the language file.
        //
        // If you want to use any extra language items - ie extra text on your admin page for any reason,
        // then just add an extra line to the $text_strings array with the name you want to call the extra text,
        // then add the same named item to the $_[] array in the language file.
        //
        // 'my_module_example' is added here as an example of how to add - see admin/language/english/module/my_module.php for the
        // other required part.

        $text_strings = array(
            'heading_title',
            'text_edit',
            'column_geo_description',
            'column_dict_description',
            'help_geo',
            'help_dict',
            'help_geo_ru_en',
            'button_en_ru',
            'button_ru_en',
            'button_save',
            'button_cancel',
            'button_add_module',
            'button_remove',
        );

        foreach ($text_strings as $text) {
            $data[$text] = $this->language->get($text);
        }
        //END LANGUAGE


        //This creates an error message. The error['warning'] variable is set by the call to function validate() in this controller (below)
        if (isset($error['warning'])) {
            $data['error_warning'] = $error['warning'];
        } else {
            $data['error_warning'] = '';
        }

        $data['token'] = $this->session->data['token'];

        //SET UP BREADCRUMB TRAIL. YOU WILL NOT NEED TO MODIFY THIS UNLESS YOU CHANGE YOUR MODULE NAME.
        $data['breadcrumbs'] = array();

        $data['breadcrumbs'][] = array(
            'text'      => $this->language->get('text_home'),
            'href'      => $this->url->link('common/home', 'token=' . $this->session->data['token'], 'SSL'),
            'separator' => false
        );

        $data['breadcrumbs'][] = array(
            'text'      => $this->language->get('text_module'),
            'href'      => $this->url->link('extension/module', 'token=' . $this->session->data['token'], 'SSL'),
            'separator' => ' :: '
        );

        $data['breadcrumbs'][] = array(
            'text'      => $this->language->get('heading_title'),
            'href'      => $this->url->link('module/rbose_russian_language', 'token=' . $this->session->data['token'], 'SSL'),
            'separator' => ' :: '
        );

        $data['action'] = $this->url->link('module/rbose_russian_language', 'token=' . $this->session->data['token'], 'SSL');

        $data['cancel'] = $this->url->link('extension/module', 'token=' . $this->session->data['token'], 'SSL');


        //This code handles the situation where you have multiple instances of this module, for different layouts.
        $data['modules'] = array();

        if (isset($this->request->post['russian_language_module'])) {
            $data['modules'] = $this->request->post['russian_language_module'];
        } elseif ($this->config->get('russian_language_module')) {
            $data['modules'] = $this->config->get('russian_language_module');
        }

        //Send the output.
        $data['header'] = $this->load->controller('common/header');
        $data['column_left'] = $this->load->controller('common/column_left');
        $data['footer'] = $this->load->controller('common/footer');

        $this->response->setOutput($this->load->view('module/rbose_russian_language.tpl', $data));
    }

    /*
     *
     * This function is called to ensure that the settings chosen by the admin user are allowed/valid.
     * You can add checks in here of your own.
     *
     */
    private function validate() {
        if (!$this->user->hasPermission('modify', 'module/rbose_russian_language')) {
            $this->error['warning'] = $this->language->get('error_permission');
        }

        if (!$this->error) {
            return TRUE;
        } else {
            return FALSE;
        }
    }

    public function translateGeo() {
        $this->load->language('module/rbose_russian_language');

        if (isset($this->request->get['from']) && isset($this->request->get['from'])) {
            $this->load->model('module/rbose_russian_language');
            $processed = $this->model_module_rbose_russian_language->translateGeo(
                $this->request->get['from'],
                $this->request->get['to']
            );
            $result = sprintf($this->language->get('msg_rows_affected'), $processed);
        }
        else {
            $result = $this->language->get('error_args');
        }
        $this->response->setOutput($result);
    }

    public function translateTerms() {
        $this->load->language('module/rbose_russian_language');

        $this->load->model('module/rbose_russian_language');
        $processed = $this->model_module_rbose_russian_language->translateTerms();
        $result = sprintf($this->language->get('msg_rows_affected'), $processed);
        $this->response->setOutput($result);
    }

}
